[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,115 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief An AXPY kernel implemented with a task of the CUDA stream backend
|
||||
*
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
#include <mutex>
|
||||
#include <thread>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
static __global__ void cuda_sleep_kernel(long long int clock_cnt)
|
||||
{
|
||||
long long int start_clock = clock64();
|
||||
long long int clock_offset = 0;
|
||||
while (clock_offset < clock_cnt)
|
||||
{
|
||||
clock_offset = clock64() - start_clock;
|
||||
}
|
||||
}
|
||||
|
||||
void cuda_sleep(double ms, cudaStream_t stream)
|
||||
{
|
||||
int device;
|
||||
cudaGetDevice(&device);
|
||||
|
||||
// cudaDevAttrClockRate: Peak clock frequency in kilohertz;
|
||||
int clock_rate;
|
||||
cudaDeviceGetAttribute(&clock_rate, cudaDevAttrClockRate, device);
|
||||
|
||||
long long int clock_cnt = (long long int) (ms * clock_rate);
|
||||
cuda_sleep_kernel<<<1, 1, 0, stream>>>(clock_cnt);
|
||||
}
|
||||
|
||||
__global__ void axpy(double a, slice<const double> x, slice<double> y)
|
||||
{
|
||||
int tid = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
int nthreads = gridDim.x * blockDim.x;
|
||||
|
||||
for (int i = tid; i < x.size(); i += nthreads)
|
||||
{
|
||||
y(i) += a * x(i);
|
||||
}
|
||||
}
|
||||
|
||||
double X0(int i)
|
||||
{
|
||||
return sin((double) i);
|
||||
}
|
||||
|
||||
double Y0(int i)
|
||||
{
|
||||
return cos((double) i);
|
||||
}
|
||||
|
||||
void mytask(stream_ctx ctx, int /*id*/, logical_data<slice<double>> lX)
|
||||
{
|
||||
// std::cout << "Thread " << id << " is executing.\n";
|
||||
|
||||
const size_t N = 16;
|
||||
|
||||
double alpha = 3.14;
|
||||
|
||||
auto lY = ctx.logical_data<double>(N);
|
||||
ctx.task(lY.write())->*[](cudaStream_t, auto) {};
|
||||
|
||||
/* Compute Y = Y + alpha X */
|
||||
for (size_t i = 0; i < 10; i++)
|
||||
{
|
||||
ctx.task(lX.read(), lY.rw())->*[&](cudaStream_t s, auto dX, auto dY) {
|
||||
axpy<<<16, 128, 0, s>>>(alpha, dX, dY);
|
||||
cuda_sleep(100.0, s);
|
||||
};
|
||||
}
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
stream_ctx ctx;
|
||||
const size_t N = 16;
|
||||
auto lX = ctx.logical_data<double>(N);
|
||||
ctx.task(lX.write())->*[](cudaStream_t, auto) {};
|
||||
|
||||
std::vector<std::thread> threads;
|
||||
// Launch 8 threads.
|
||||
for (int i = 0; i < 10; ++i)
|
||||
{
|
||||
threads.emplace_back(mytask, ctx, i, lX);
|
||||
}
|
||||
|
||||
// Wait for all threads to complete.
|
||||
for (auto& th : threads)
|
||||
{
|
||||
th.join();
|
||||
}
|
||||
|
||||
ctx.task(lX.rw())->*[&](cudaStream_t s, auto) {
|
||||
cuda_sleep(100.0, s);
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
@@ -1,85 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2025 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief Ensure a graph_ctx can be used concurrently
|
||||
*
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
#include <mutex>
|
||||
#include <thread>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
__global__ void axpy(slice<int> y, slice<const int> x, int a)
|
||||
{
|
||||
int tid = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
int nthreads = gridDim.x * blockDim.x;
|
||||
|
||||
for (int i = tid; i < x.size(); i += nthreads)
|
||||
{
|
||||
y(i) += a * x(i);
|
||||
}
|
||||
}
|
||||
|
||||
void mytask(graph_ctx ctx, int /*id*/)
|
||||
{
|
||||
const size_t N = 16;
|
||||
|
||||
int alpha = 3;
|
||||
|
||||
auto lX = ctx.logical_data<int>(N);
|
||||
auto lY = ctx.logical_data<int>(N);
|
||||
|
||||
ctx.parallel_for(lX.shape(), lX.write(), lY.write())->*[] __device__(size_t i, auto x, auto y) {
|
||||
x(i) = (1 + i);
|
||||
y(i) = (2 + i * i);
|
||||
};
|
||||
|
||||
/* Compute Y = Y + alpha X */
|
||||
for (size_t i = 0; i < 200; i++)
|
||||
{
|
||||
ctx.task(lY.rw(), lX.read())->*[alpha](cudaStream_t stream, auto dY, auto dX) {
|
||||
axpy<<<128, 64, 0, stream>>>(dY, dX, alpha);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.host_launch(lX.read(), lY.read())->*[alpha](auto x, auto y) {
|
||||
for (size_t i = 0; i < N; i++)
|
||||
{
|
||||
EXPECT(x(i) == 1 + i);
|
||||
EXPECT(y(i) == 2 + i * i + 200 * alpha * x(i));
|
||||
}
|
||||
};
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
graph_ctx ctx;
|
||||
|
||||
::std::vector<::std::thread> threads;
|
||||
// Launch threads
|
||||
for (int i = 0; i < 10; ++i)
|
||||
{
|
||||
threads.emplace_back(mytask, ctx, i);
|
||||
}
|
||||
|
||||
// Wait for all threads to complete.
|
||||
for (auto& th : threads)
|
||||
{
|
||||
th.join();
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
@@ -1,74 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2025 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief Ensure a graph_ctx can be used concurrently
|
||||
*
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
#include <mutex>
|
||||
#include <thread>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
void mytask(graph_ctx ctx, int /*id*/)
|
||||
{
|
||||
const size_t N = 16;
|
||||
|
||||
int alpha = 3;
|
||||
|
||||
auto lX = ctx.logical_data<int>(N);
|
||||
auto lY = ctx.logical_data<int>(N);
|
||||
|
||||
ctx.parallel_for(lX.shape(), lX.write(), lY.write())->*[] __device__(size_t i, auto x, auto y) {
|
||||
x(i) = (1 + i);
|
||||
y(i) = (2 + i * i);
|
||||
};
|
||||
|
||||
/* Compute Y = Y + alpha X */
|
||||
for (size_t i = 0; i < 200; i++)
|
||||
{
|
||||
ctx.parallel_for(lY.shape(), lY.rw(), lX.read())->*[alpha] __device__(size_t i, auto dY, auto dX) {
|
||||
dY(i) += alpha * dX(i);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.host_launch(lX.read(), lY.read())->*[alpha](auto x, auto y) {
|
||||
for (size_t i = 0; i < N; i++)
|
||||
{
|
||||
EXPECT(x(i) == 1 + i);
|
||||
EXPECT(y(i) == 2 + i * i + 200 * alpha * x(i));
|
||||
}
|
||||
};
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
graph_ctx ctx;
|
||||
|
||||
::std::vector<::std::thread> threads;
|
||||
// Launch threads
|
||||
for (int i = 0; i < 10; ++i)
|
||||
{
|
||||
threads.emplace_back(mytask, ctx, i);
|
||||
}
|
||||
|
||||
// Wait for all threads to complete.
|
||||
for (auto& th : threads)
|
||||
{
|
||||
th.join();
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
@@ -1,114 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief An AXPY kernel implemented with a task of the CUDA stream backend
|
||||
*
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
#include <mutex>
|
||||
#include <thread>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
static __global__ void cuda_sleep_kernel(long long int clock_cnt)
|
||||
{
|
||||
long long int start_clock = clock64();
|
||||
long long int clock_offset = 0;
|
||||
while (clock_offset < clock_cnt)
|
||||
{
|
||||
clock_offset = clock64() - start_clock;
|
||||
}
|
||||
}
|
||||
|
||||
void cuda_sleep(double ms, cudaStream_t stream)
|
||||
{
|
||||
int device;
|
||||
cudaGetDevice(&device);
|
||||
|
||||
// cudaDevAttrClockRate: Peak clock frequency in kilohertz;
|
||||
int clock_rate;
|
||||
cudaDeviceGetAttribute(&clock_rate, cudaDevAttrClockRate, device);
|
||||
|
||||
long long int clock_cnt = (long long int) (ms * clock_rate);
|
||||
cuda_sleep_kernel<<<1, 1, 0, stream>>>(clock_cnt);
|
||||
}
|
||||
|
||||
__global__ void axpy(double a, slice<const double> x, slice<double> y)
|
||||
{
|
||||
int tid = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
int nthreads = gridDim.x * blockDim.x;
|
||||
|
||||
for (int i = tid; i < x.size(); i += nthreads)
|
||||
{
|
||||
y(i) += a * x(i);
|
||||
}
|
||||
}
|
||||
|
||||
double X0(int i)
|
||||
{
|
||||
return sin((double) i);
|
||||
}
|
||||
|
||||
double Y0(int i)
|
||||
{
|
||||
return cos((double) i);
|
||||
}
|
||||
|
||||
void mytask(stream_ctx ctx, int /*id*/)
|
||||
{
|
||||
// std::cout << "Thread " << id << " is executing.\n";
|
||||
|
||||
const size_t N = 16;
|
||||
|
||||
double alpha = 3.14;
|
||||
|
||||
auto lX = ctx.logical_data<double>(N);
|
||||
auto lY = ctx.logical_data<double>(N);
|
||||
|
||||
ctx.parallel_for(lX.shape(), lX.write())->*[] __device__(size_t i, auto x) {
|
||||
x(i) = 1.0;
|
||||
};
|
||||
|
||||
ctx.task(lY.write())->*[](cudaStream_t, auto) {};
|
||||
|
||||
/* Compute Y = Y + alpha X */
|
||||
for (size_t i = 0; i < 10; i++)
|
||||
{
|
||||
ctx.task(lX.read(), lY.rw())->*[&](cudaStream_t s, auto dX, auto dY) {
|
||||
axpy<<<16, 128, 0, s>>>(alpha, dX, dY);
|
||||
cuda_sleep(100.0, s);
|
||||
};
|
||||
}
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
stream_ctx ctx;
|
||||
|
||||
std::vector<std::thread> threads;
|
||||
// Launch 8 threads.
|
||||
for (int i = 0; i < 10; ++i)
|
||||
{
|
||||
threads.emplace_back(mytask, ctx, i);
|
||||
}
|
||||
|
||||
// Wait for all threads to complete.
|
||||
for (auto& th : threads)
|
||||
{
|
||||
th.join();
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
@@ -1,112 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief An AXPY kernel implemented with a task of the CUDA stream backend
|
||||
*
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
|
||||
|
||||
#include <mutex>
|
||||
#include <thread>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
static __global__ void cuda_sleep_kernel(long long int clock_cnt)
|
||||
{
|
||||
long long int start_clock = clock64();
|
||||
long long int clock_offset = 0;
|
||||
while (clock_offset < clock_cnt)
|
||||
{
|
||||
clock_offset = clock64() - start_clock;
|
||||
}
|
||||
}
|
||||
|
||||
void cuda_sleep(double ms, cudaStream_t stream)
|
||||
{
|
||||
int device;
|
||||
cudaGetDevice(&device);
|
||||
|
||||
// cudaDevAttrClockRate: Peak clock frequency in kilohertz;
|
||||
int clock_rate;
|
||||
cudaDeviceGetAttribute(&clock_rate, cudaDevAttrClockRate, device);
|
||||
|
||||
long long int clock_cnt = (long long int) (ms * clock_rate);
|
||||
cuda_sleep_kernel<<<1, 1, 0, stream>>>(clock_cnt);
|
||||
}
|
||||
|
||||
__global__ void axpy(double a, slice<const double> x, slice<double> y)
|
||||
{
|
||||
int tid = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
int nthreads = gridDim.x * blockDim.x;
|
||||
|
||||
for (int i = tid; i < x.size(); i += nthreads)
|
||||
{
|
||||
y(i) += a * x(i);
|
||||
}
|
||||
}
|
||||
|
||||
double X0(int i)
|
||||
{
|
||||
return sin((double) i);
|
||||
}
|
||||
|
||||
double Y0(int i)
|
||||
{
|
||||
return cos((double) i);
|
||||
}
|
||||
|
||||
void mytask(stream_ctx ctx, int /*id*/)
|
||||
{
|
||||
// std::cout << "Thread " << id << " is executing.\n";
|
||||
|
||||
const size_t N = 16;
|
||||
|
||||
double alpha = 3.14;
|
||||
|
||||
auto lX = ctx.logical_data<double>(N);
|
||||
auto lY = ctx.logical_data<double>(N);
|
||||
|
||||
ctx.task(lX.write())->*[](cudaStream_t, auto) {};
|
||||
|
||||
ctx.task(lY.write())->*[](cudaStream_t, auto) {};
|
||||
|
||||
/* Compute Y = Y + alpha X */
|
||||
for (size_t i = 0; i < 10; i++)
|
||||
{
|
||||
ctx.task(lX.read(), lY.rw())->*[&](cudaStream_t s, auto dX, auto dY) {
|
||||
axpy<<<16, 128, 0, s>>>(alpha, dX, dY);
|
||||
cuda_sleep(100.0, s);
|
||||
};
|
||||
}
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
stream_ctx ctx;
|
||||
|
||||
std::vector<std::thread> threads;
|
||||
// Launch 8 threads.
|
||||
for (int i = 0; i < 10; ++i)
|
||||
{
|
||||
threads.emplace_back(mytask, ctx, i);
|
||||
}
|
||||
|
||||
// Wait for all threads to complete.
|
||||
for (auto& th : threads)
|
||||
{
|
||||
th.join();
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
Reference in New Issue
Block a user